@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.125-15-gfee1b85
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.126-10-g8008cf7
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.126';
+our $VERSION = '0.127';
 
 use Moose;
 with
@@ -14,7 +14,7 @@ with
     'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 
 use Dist::Zilla::Util;
-use Moose::Util::TypeConstraints qw(enum subtype where);
+use Moose::Util::TypeConstraints qw(enum subtype where class_type);
 use List::Util 1.45 qw(first any uniq);
 use Module::Runtime 'require_module';
 use Devel::CheckBin 'can_run';
@@ -140,7 +140,7 @@ my %extra_args = (
 # plugins that use the network when they run
 sub _network_plugins
 {
-    my @network_plugins = qw(
+    qw(
         PromptIfStale
         Test::Pod::LinkCheck
         Test::Pod::No404s
@@ -150,9 +150,6 @@ sub _network_plugins
         UploadToCPAN
         Git::Push
     );
-    my %network_plugins;
-    @network_plugins{ map { Dist::Zilla::Util->expand_config_package_name($_) } @network_plugins } = () x @network_plugins;
-    %network_plugins;
 }
 
 has _has_bash => (
@@ -162,6 +159,35 @@ has _has_bash => (
     default => sub { !!can_run('bash') },
 );
 
+# note this is applied to the plugin list in Dist::Zilla::Role::PluginBundle::PluginRemover,
+# but we also need to use it here to be sure we are not adding configs that are only needed
+# by plugins that will be subsequently removed.
+has _removed_plugins => (
+    isa => 'HashRef[Str]',
+    init_arg => undef,
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        my $remove = $self->payload->{ $self->plugin_remover_attribute } // [];
+        my %removed; @removed{@$remove} = (!!1) x @$remove;
+        \%removed;
+    },
+    traits => ['Hash'],
+    handles => { _plugin_removed => 'exists' },
+);
+
+# this attribute and its supporting code is a candidate to be extracted out into its own role,
+# for re-use in other bundles
+has _develop_requires => (
+    isa => class_type('CPAN::Meta::Requirements'),
+    lazy => 1,
+    default => sub { CPAN::Meta::Requirements->new },
+    handles => {
+        _add_minimum_develop_requires => 'add_minimum',
+        _develop_requires_as_string_hash => 'as_string_hash',
+    },
+);
+
 # files that might be in the repository that should never be gathered
 my @never_gather = qw(
     Makefile.PL ppport.h README.md README.pod META.json
@@ -169,6 +195,20 @@ my @never_gather = qw(
     inc/ExtUtils/MakeMaker/Dist/Zilla/Develop.pm
 );
 
+sub BUILD
+{
+    my $self = shift;
+
+    if ($self->airplane)
+    {
+        warn '[@Author::ETHER] ' . colored('building in airplane mode - plugins requiring the network are skipped, and releases are not permitted', 'yellow') . "\n";
+
+        # doing this before running configure means we can be sure we update the removal list before
+        # our _removed_plugins attribute is built.
+        push @{ $self->payload->{ $self->plugin_remover_attribute } }, $self->_network_plugins;
+    }
+}
+
 sub configure
 {
     my $self = shift;
@@ -201,14 +241,13 @@ sub configure
             and (not exists $self->payload->{'Test::MinimumVersion.max_target_perl'}
                  or $self->payload->{'Test::MinimumVersion.max_target_perl'} < '5.008');
 
-    my $remove = $self->payload->{ $self->plugin_remover_attribute } // [];
-    my %removed; @removed{@$remove} = (!!1) x @$remove;
-
     warn '[@Author::ETHER] ', colored('.git is missing and META.json is present -- this looks like a CPAN download rather than a git repository. You should probably run '
             . (-f 'Build.PL' ? 'perl Build.PL; ./Build' : 'perl Makefile.PL; make') . ' instead of using dzil commands!', 'yellow'), "\n"
-        if not -d '.git' and -f 'META.json' and not exists $removed{'Git::GatherDir'};
+        if not -d '.git' and -f 'META.json' and not $self->_plugin_removed('Git::GatherDir');
 
     # only set x_static_install using auto mode for my own distributions
+    # (for all other distributions, set explicitly to on or off)
+    # Note that this is just the default; if a dist.ini changed these values, ConfigSlicer will apply it later
     my $static_install_mode = $self->payload->{'StaticInstall.mode'} // 'auto';
     my $static_install_dry_run = ($static_install_mode eq 'auto'
             and $self->authority ne 'cpan:ETHER') ? 1 : 0;
@@ -270,7 +309,7 @@ sub configure
         [ 'MojibakeTests'       => { ':version' => '0.8' } ],
         [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1,
             version_extractor => ( ( any { $_ ne 'MakeMaker' } $self->installer ) ? 'Module::Metadata' : 'ExtUtils::MakeMaker' ),
-            include => [ sort ( qw(autodie JSON::PP Sub::Name YAML), exists $removed{PodCoverageTests} ? () : 'Pod::Coverage' ) ] } ],
+            include => [ sort ( qw(autodie JSON::PP Sub::Name YAML), $self->_plugin_removed('PodCoverageTests') ? () : 'Pod::Coverage' ) ] } ],
         [ 'Test::Portability'   => { ':version' => '2.000007' } ],
         [ 'Test::CleanNamespaces' => { ':version' => '0.006' } ],
 
@@ -390,20 +429,8 @@ sub configure
     push @plugins,
         [ 'Run::AfterRelease'   => 'install release' => { ':version' => '0.031', fatal_errors => 0, run => 'cpanm http://' . $username . ':' . $password . '@pause.perl.org/pub/PAUSE/authors/id/' . substr($username, 0, 1).'/'.substr($username,0,2).'/'.$username.'/%a' } ] if $username and $password;
 
-    if ($self->airplane)
-    {
-        my %network_plugins = $self->_network_plugins;
-        warn '[@Author::ETHER] ' . colored('building in airplane mode - plugins requiring the network are skipped, and releases are not permitted', 'yellow') . "\n";
-        @plugins = grep {
-            my $plugin = Dist::Zilla::Util->expand_config_package_name(
-                !ref($_) ? $_ : ref eq 'ARRAY' ? $_->[0] : die 'wtf'
-            );
-            not exists $network_plugins{$plugin}
-        } @plugins;
-
-        # halt release after pre-release checks, but before ConfirmRelease
-        push @plugins, 'BlockRelease';
-    }
+    # halt release after pre-release checks, but before ConfirmRelease
+    push @plugins, 'BlockRelease' if $self->airplane;
 
     push @plugins, (
         [ 'Run::AfterRelease'   => 'release complete' => { ':version' => '0.038', quiet => 1, eval => [ qq{print "release complete!\\xa"} ] } ],
@@ -411,11 +438,43 @@ sub configure
         'ConfirmRelease',
     );
 
-    my $plugin_requirements = CPAN::Meta::Requirements->new;
+    # method modifier will also apply default configs, compile develop prereqs
+    $self->add_plugins(@plugins);
+
+    # if ModuleBuildTiny(::*) is being used, disable its static option if
+    # [StaticInstall] is being run with mode=off or dry_run=1
+    if (($static_install_mode eq 'off' or $static_install_dry_run)
+        and any { /^ModuleBuildTiny/ } $self->installer)
+    {
+        my $mbt = Dist::Zilla::Util->expand_config_package_name('ModuleBuildTiny');
+        my $mbt_spec = first { $_->[1] =~ /^$mbt/ } @{ $self->plugins };
+
+        $mbt_spec->[-1]{static} = 'no';
+    }
+
+    # ensure that additional optional plugins are declared in prereqs
+    $self->add_plugins(
+        [ 'Prereqs' => bundle_plugins =>
+        { '-phase' => 'develop', '-relationship' => 'requires',
+          %{ $self->_develop_requires_as_string_hash } } ]
+    );
+
+    # listed last, to be sure we run at the very end of each phase
+    $self->add_plugins(
+        [ 'VerifyPhases' => 'PHASE VERIFICATION' => { ':version' => '0.015' } ]
+    ) if ($ENV{USER} // '') eq 'ether';
+}
+
+# determine develop prereqs, and apply default configs (respecting superclasses, roles)
+around add_plugins => sub
+{
+    my ($orig, $self, @plugins) = @_;
+
     foreach my $plugin_spec (@plugins = map { ref $_ ? $_ : [ $_ ] } @plugins)
     {
-        next if $removed{$plugin_spec->[0]}
-            or $plugin_spec->[0] eq 'BlockRelease';  # temporary hack, due to plugin ordering
+        next if $self->_plugin_removed($plugin_spec->[0])
+            or $plugin_spec->[0] eq 'BlockRelease'
+            or $plugin_spec->[0] eq 'VerifyPhases';
 
         my $plugin = Dist::Zilla::Util->expand_config_package_name($plugin_spec->[0]);
         require_module($plugin);
@@ -428,7 +487,7 @@ sub configure
             my %configs = %{ $extra_args{$module} };    # copy, not reference!
 
             # don't keep :version unless it matches the package exactly, but still respect the prereq
-            $plugin_requirements->add_minimum($module => delete $configs{':version'})
+            $self->_add_minimum_develop_requires($module => delete $configs{':version'})
                 if exists $configs{':version'} and $module ne $plugin;
 
             # we don't need to worry about overwriting the payload with defaults, as
@@ -437,31 +496,11 @@ sub configure
         }
 
         # record develop prereq
-        $plugin_requirements->add_minimum($plugin => $payload->{':version'} // 0);
+        $self->_add_minimum_develop_requires($plugin => $payload->{':version'} // 0);
     }
 
-    # if ModuleBuildTiny(::*) is being used, disable its static option if
-    # [StaticInstall] is being run with mode=off or dry_run=1
-    if (($static_install_mode eq 'off' or $static_install_dry_run)
-        and any { /^ModuleBuildTiny/ } $self->installer)
-    {
-        my $mbt_spec = first { $_->[0] =~ /^ModuleBuildTiny/ } @plugins;
-        $mbt_spec->[-1]{static} = 'no';
-    }
-
-    # ensure that additional optional plugins are declared in prereqs
-    unshift @plugins,
-        [ 'Prereqs' => bundle_plugins =>
-            { '-phase' => 'develop', '-relationship' => 'requires',
-              %{ $plugin_requirements->as_string_hash } } ];
-
-    push @plugins, (
-        # listed last, to be sure we run at the very end of each phase
-        [ 'VerifyPhases' => 'PHASE VERIFICATION' => { ':version' => '0.015' } ],
-    ) if ($ENV{USER} // '') eq 'ether';
-
-    $self->add_plugins(@plugins);
-}
+    return $self->$orig(@plugins);
+};
 
 # return username, password from ~/.pause
 sub _pause_config
@@ -490,7 +529,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.126
+version 0.127
 
 =head1 SYNOPSIS
 
