@@ -9,6 +9,7 @@ our @EXPORT = qw(
     no_git_tempdir
     git_in_path
     notexists
+    recursive_child_files
 );
 
 use Test::More 0.96;
@@ -144,7 +145,7 @@ sub no_git_tempdir
 sub git_in_path
 {
     my $in_git;
-    my $dir = $_[0];
+    my $dir = path($_[0]);
     my $count = 0;
     while (not $dir->is_rootdir) {
         # this should never happen.
@@ -179,4 +180,16 @@ sub notexists
     });
 }
 
+# simple Path::Tiny helper: like `find $dir -type f`
+sub recursive_child_files
+{
+    my $dir = shift;
+    my @found_files;
+    $dir->visit(
+        sub { push @found_files, $_->relative($dir)->stringify if -f },
+        { recurse => 1 },
+    );
+    @found_files;
+}
+
 1;
